@@ -126,10 +126,10 @@ class SE2(sp.SMPose):
     ArithmeticError()
     
 
-if __name__ == '__main__':
+if __name__ == '__main__':  # pragma: no cover
  
     import pathlib
     import os.path
     
-    runfile(os.path.join(pathlib.Path(__file__).parent.absolute(), "test_pose2d.py") )
+    exec(open(os.path.join(pathlib.Path(__file__).parent.absolute(), "test_pose2d.py")).read() )
     
\ No newline at end of file
